#include "Win32WebRequest.h"

#include "StringUtils.h"
#include "HttpRequest.h"

Win32WebRequest::Win32WebRequest()
	: mBuffer(DEFAULT_BUFFER_SIZE)
{
	mIsValid = mBuffer.isValid();
	mHandle = reinterpret_cast<PHTTP_REQUEST>(mBuffer.getBuffer());
}

bool Win32WebRequest::isValid() const
{
	return mIsValid;
}

void Win32WebRequest::zeroBufferMemory()
{
	::RtlZeroMemory(mHandle, mWorkingBufferSize);
}

PHTTP_REQUEST Win32WebRequest::getHandle() const
{
	return mHandle;
}

unsigned Win32WebRequest::getBufferSize() const
{
	return mWorkingBufferSize;
}

void Win32WebRequest::resizeBuffer(unsigned size)
{
	mWorkingBufferSize = size;
	mBuffer.reset(mWorkingBufferSize);
	if (!mBuffer.isValid())
	{
		mIsValid = false;
		return;
	}
	mHandle = reinterpret_cast<PHTTP_REQUEST>(mBuffer.getBuffer());
}

std::string Win32WebRequest::getUrlFromRequest() const
{
	const std::wstring wide_url = mHandle->CookedUrl.pFullUrl;
	return StringUtils::convert(wide_url);
}

HttpRequest Win32WebRequest::getRequest() const
{
	HttpRequest::Verb verb;
	switch (mHandle->Verb)
	{
	case HttpVerbGET:
		verb = HttpRequest::Verb::GET;
	case HttpVerbPOST:
		verb = HttpRequest::Verb::POST;
	default:
		verb = HttpRequest::Verb::UNKNOWN;
		break;
	}

	HttpRequest request(verb, getUrlFromRequest());
	return request;
}